#include "SoftwareSerial.h"
SoftwareSerial port(12,13);

#define RELAY1_PIN 7
#define RELAY2_PIN 8
#define RELAY3_PIN 9
#define RELAY4_PIN 10

String relay1_status = "0";
String relay2_status = "0";
String relay3_status = "0";
String relay4_status = "0";

int isOn = 0;

#include "EasyVR.h"
EasyVR easyvr(port);

//Groups and Commands
enum Groups
{
  GROUP_0  = 0,
  GROUP_1  = 1,
};

enum Group0 
{
  G0_SMART_LIGUE = 0,
};

enum Group1 
{
  G1_LIGUE_TOMADA1 = 10,
  G1_LIGUE_LUZ = 11,
  G1_LIGUE_VENTILADOR = 12,
  G1_DES_TOMADA1 = 14,
  G1_DES_LUZ = 15,
  G1_DES_VENTILADOR = 16,
  G1_SMART_DESLIGUE = 9,
};

EasyVRBridge bridge;

int lred = 5;
int lgreen = 4;
int lblue = 3;

int get_led;

int8_t group, idx;

int blink_rgb() {
  digitalWrite(lred, HIGH);
  digitalWrite(lgreen, HIGH);
  digitalWrite(lblue, HIGH);
  delay(100); 
}

int turnOff_leds() {
  digitalWrite(lred, LOW);
  digitalWrite(lgreen, LOW);
  digitalWrite(lblue, LOW);
  delay(100);
}

int turnOff_relays(){
  digitalWrite(RELAY1_PIN, LOW);
  relay1_status = "0";
  digitalWrite(RELAY2_PIN, LOW);
  relay2_status = "0";
  digitalWrite(RELAY3_PIN, LOW);
  relay3_status = "0";
  digitalWrite(RELAY4_PIN, LOW);
  relay4_status = "0";
}


void setup()
{
  pinMode(lred, OUTPUT);
  pinMode(lgreen, OUTPUT);
  pinMode(lblue, OUTPUT);
  pinMode(7, OUTPUT);
  pinMode(RELAY1_PIN, OUTPUT);
  pinMode(RELAY2_PIN, OUTPUT);
  pinMode(RELAY3_PIN, OUTPUT);
  pinMode(RELAY4_PIN, OUTPUT);

  // bridge mode?
  if (bridge.check())
  {
    cli();
    bridge.loop(0, 1, 12, 13);
  }
  // run normally
  Serial.begin(57600);
  Serial.flush();
  Serial.println("SmartRelay - Debug mode | Nelson | Pedro | PUCPR");
  Serial.println("------------------------------------------------");
  port.begin(9600);

  if (!easyvr.detect())
  {
    Serial.println("- You've got a problem: -> Voice module (EasyVR) not detected!");
    for (;;);
  }

  easyvr.setPinOutput(EasyVR::IO1, LOW);
  Serial.println("- Voice module (EasyVR) detected!");
  Serial.println("- Waiting for the trigger word...");
  easyvr.setTimeout(2);
  easyvr.setLanguage(0);
  easyvr.setLevel(1);

  tone(6, 1000, 100);
  delay(100);
  tone(6, 1500, 100);
  delay(100);
  tone(6, 1000, 100);
  delay(100);
  tone(6, 1500, 100);
  delay(100);

  group = EasyVR::TRIGGER; //<-- start group (customize)
}

void action();

void loop()
{

  easyvr.setPinOutput(EasyVR::IO1, HIGH); // LED on (listening)

  //Serial.print("Say a command in Group ");
  //Serial.println(group);
  easyvr.recognizeCommand(group);

  // can do some processing while waiting for a spoken command
  do
  {
    String content = "";
    char character;
    while(Serial.available()) {
      character = Serial.read();
      content.concat(character);
      delay(5);

      if(content == "A"){
        Serial.println("R1" +relay1_status);
      }
      if(content == "B"){
        Serial.println("R2" +relay2_status);
      }
      if(content == "C"){
        Serial.println("R3" +relay3_status);
      }
      if(content == "D"){
        Serial.println("R4" +relay4_status);
      }
      if(content == "10"){
        digitalWrite(RELAY1_PIN, LOW);
        Serial.println("- Relay #1 Off");
        relay1_status = "0";
      }
      if(content == "11"){
        digitalWrite(RELAY1_PIN, HIGH);
        Serial.println("- Relay #1 On");
        relay1_status = "1";
      }
      if(content == "20"){
        digitalWrite(RELAY2_PIN, LOW);
        Serial.println("- Relay #2 Off");
        relay2_status = "0";
      }
      if(content == "21"){
        digitalWrite(RELAY2_PIN, HIGH);
        Serial.println("- Relay #2 On");
        relay2_status = "1";
      }
      if(content == "30"){
        digitalWrite(RELAY3_PIN, LOW);
        Serial.println("- Relay #3 Off");
        relay3_status = "0";
      }
      if(content == "31"){
        digitalWrite(RELAY3_PIN, HIGH);
        Serial.println("- Relay #3 On");
        relay3_status = "1";
      }
      if(content == "40"){
        digitalWrite(RELAY4_PIN, LOW);
        Serial.println("- Relay #4 Off");
        relay4_status = "0";
      }
      if(content == "41"){
        digitalWrite(RELAY4_PIN, HIGH);
        Serial.println("- Relay #4 On");
        relay4_status = "1";
      }
    }
    if(isOn == 1) {
      digitalWrite(lgreen, HIGH);
      delay(90);
      digitalWrite(lgreen, LOW);
    }
  }
  while (!easyvr.hasFinished());

  easyvr.setPinOutput(EasyVR::IO1, LOW); // LED off

  idx = easyvr.getWord();
  if (idx >= 0)
  {
    // built-in trigger (ROBOT)
    // group = GROUP_X; <-- jump to another group X
    return;
  }
  idx = easyvr.getCommand();
  if (idx >= 0)
  {
    // print debug message
    uint8_t train = 0;
    char name[32];
    Serial.print("Command: ");
    Serial.print(idx);
    if (easyvr.dumpCommand(group, idx, name, train))
    {
      Serial.print(" = ");
      Serial.println(name);
    }
    else
      Serial.println();
    //easyvr.playSound(0, EasyVR::VOL_FULL);
    // perform some action
    action();
  }
  else // errors or timeout
  {
    if (easyvr.isTimeout()) {
      //Serial.println("Timed out, try again...");
    }
    int16_t err = easyvr.getError();
    if (err >= 0)
    {
      Serial.print("- Error: ");
      Serial.println(err, HEX);
      turnOff_leds();
      tone(6, 900, 100);
      digitalWrite(lred, HIGH);
      delay(100);
      tone(6, 950, 100);
      digitalWrite(lred, LOW);
      delay(100);
      tone(6, 900, 100);
      digitalWrite(lred, HIGH);
      delay(100);
      tone(6, 950, 100);
      digitalWrite(lred, LOW);
      delay(100);
    }
  }
}

void action()
{
  switch (group)
  {
  case GROUP_0:
    switch (idx)
    {
    case G0_SMART_LIGUE:
      // write your action code here
      tone(6, 1500, 100);
      delay(100);
      blink_rgb();
      turnOff_leds();
      group = GROUP_1; // <-- or jump to another group X for composite commands
      isOn = 1;
      Serial.println("- Hi there, from now on say your prays...");     
      break;
    }
    break;
  case GROUP_1:
    switch (idx)
    {
    case G1_SMART_DESLIGUE:
      // write your action code here      
      group = GROUP_0; //<-- or jump to another group X for composite commands
      tone(6, 1500, 100);
      delay(100);
      turnOff_relays();
      blink_rgb();
      turnOff_leds();
      isOn = 0;
      Serial.println("- See ya later!");
      break;
    case G1_LIGUE_TOMADA1:
      tone(6, 1500, 100);
      delay(100);
      digitalWrite(RELAY1_PIN, HIGH);
      Serial.println("Relay #1 On");
      relay1_status = "1";
      blink_rgb();
      turnOff_leds();
      break;
    case G1_LIGUE_LUZ:
      tone(6, 1500, 100);
      delay(100);
      digitalWrite(RELAY2_PIN, HIGH);
      Serial.println("- Relay #2 On");
      relay2_status = "1";
      blink_rgb();
      turnOff_leds();
      break;
    case G1_LIGUE_VENTILADOR:
      tone(6, 1500, 100);
      delay(100);
      digitalWrite(RELAY3_PIN, HIGH);
      Serial.println("- Relay #3 On");
      relay3_status = "1";
      blink_rgb();
      turnOff_leds();
      break;
    case G1_DES_TOMADA1:
      tone(6, 1500, 100);
      delay(100);
      digitalWrite(RELAY1_PIN, LOW);
      Serial.println("- Relay #1 Off");
      relay1_status = "0";
      blink_rgb();
      turnOff_leds();
      break;
    case G1_DES_LUZ:
      tone(6, 1500, 100);
      delay(100);
      digitalWrite(RELAY2_PIN, LOW);
      Serial.println("- Relay #2 Off");
      relay2_status = "0";
      blink_rgb();
      turnOff_leds();
      break;
    case G1_DES_VENTILADOR:
      tone(6, 1500, 100);
      delay(100);
      digitalWrite(RELAY3_PIN, LOW);
      Serial.println("- Relay #3 Off");
      relay3_status = "0";
      blink_rgb();
      turnOff_leds();
      break;
    }
    break;
  }
}















